@@ -111,13 +111,16 @@ def processCustomTransactionOnChain(block,name,parameters:dict,pool:dict):
     '''
     block: blockHeight
     name: Name of the rpc function (lowercase), e.g. poolswap (compositeswap is a chain of poolswaps!!! Act accordingly. Only poolswap possible)
-    parameters: key value pair of rpc parameters. 
-    pool: pool parameters - reserveA, reserveB, totalLiquidity, poolSymbol (e.g. TSLA-DUSD)
+    parameters: function keys with value - 
+        - addpoolliquidity: "amountA", "amountB" (amount of Tokens; must be in correct order depending on poolpair. E.g. TSLA-DUSD means amountA is TSLA Amount)
+        - removePoolLiquidity: "liquidity" (amount of Poolpair Tokens)
+        - poolSwap: "tokenFrom", "fromAmount", "commission", "dexFeeInPct"
+    pool: pool keys with value - "reserveA", "reserveB", "totalLiquidity", "poolSymbol" (e.g. TSLA-DUSD)
 
     RETURN:
     addpoolliquidity: amount liquidity tokens
-    removepoolliquidity: amount of TokenA and TokenB (tuple)
-    poolswap: amount of new reserveA, new reserveB and amount TokenB (tuple)
+    removepoolliquidity: amount of TokenA and TokenB (tuple) ->
+    poolswap: amount of new reserveFrom, new reserveTo and amount TokenTo (tuple)
     '''
     if 'reserveA' not in pool or 'reserveB' not in pool:
         # TODO: Raise Error
@@ -132,7 +135,11 @@ def processCustomTransactionOnChain(block,name,parameters:dict,pool:dict):
                 'error': 1,
                 'msg': 'amountA and/or amountB and/or totalLiquidity missing'
             } 
-        return chain.addPoolLiquidity(parameters['amountA'],parameters['amountB'],pool['reserveA'],pool['reserveB'],pool['totalLiquidity'])
+        liquidity = chain.addPoolLiquidity(parameters['amountA'],parameters['amountB'],pool['reserveA'],pool['reserveB'],pool['totalLiquidity'])
+        return {
+            'success': 1,
+            'liquidity': liquidity
+        }
     elif name == 'removepoolliquidity':
         if 'liquidity' not in parameters or 'totalLiquidity' not in pool:
             # TODO: Raise Error
@@ -140,7 +147,12 @@ def processCustomTransactionOnChain(block,name,parameters:dict,pool:dict):
                 'error': 1,
                 'msg': 'liquidity and/or totalLiquidity missing'
             } 
-        return chain.removePoolLiquidity(parameters['liquidity'],pool['reserveA'],pool['reserveB'],pool['totalLiquidity'])
+        (amountA,amountB) = chain.removePoolLiquidity(parameters['liquidity'],pool['reserveA'],pool['reserveB'],pool['totalLiquidity'])
+        return {
+            'success': 1,
+            'amountA': amountA,
+            'amountB': amountB
+        }
     elif name == 'poolswap':
         if 'tokenFrom' not in parameters or 'fromAmount' not in parameters or 'symbol' not in pool or 'commission' not in parameters or 'dexFeeInPct' not in parameters:
             # TODO: Raise Error
@@ -148,7 +160,13 @@ def processCustomTransactionOnChain(block,name,parameters:dict,pool:dict):
                 'error': 1,
                 'msg': 'tokenFrom and/or fromAmount and/or symbol and/or commission and/or dexFeeInPct missing'
             } 
-        return chain.poolSwap(block,parameters['tokenFrom'],pool['symbol'],parameters['fromAmount'],pool['reserveA'],pool['reserveB'],parameters['commission'],parameters['dexFeeInPct'])
+        (poolFrom,poolTo,swapped) = chain.poolSwap(block,parameters['tokenFrom'],pool['symbol'],parameters['fromAmount'],pool['reserveA'],pool['reserveB'],parameters['commission'],parameters['dexFeeInPct'])
+        return {
+            'success': 1,
+            'reserveFrom': poolFrom,
+            'reserveTo': poolTo,
+            'swapped': swapped
+        }
 
 # TODO: only working in python3.9 not in 3.8!!!
 # class TakeLoan(CustomTx.DfTx):
